# TherMod ![Temperature model in the LA area, looking north. Color scale is 0 to 30 degrees C on the top and 0 to 300 degrees C n the sides. Vertical exageration is a factor of 10.](../images/LACrossSectionTemperatureSmall.png)

This set of utilities is used to extract temperature profiles and maps from the NCM
thermal model (Boyd, 2019). Running the code requires the NCM thermal model,
NCM_TemperatureGrids.nc (<https://doi.org/10.5066/P935DT1G>), and the NCM spatial grid,
NCM_SpatialGrid.nc (<https://doi.org/10.5066/P9SBQENM>). These codes and datasets are
part of an effort to produce a three dimensional national crustal model for use with seismic
hazard studies. (<https://doi.org/10.5066/P9T96Q67>)

## Prerequisites

* [Python](https://www.python.org/downloads/) 3.8+
* [Poetry](https://python-poetry.org/) Python dependency manager

### Poetry Install

See [Poetry installation](https://python-poetry.org/docs/) instructions for more.

#### osx / linux / bashonwindows install instructions

 ```bash
 curl -sSL https://raw.githubusercontent.com/python-poetry/poetry/master/get-poetry.py | python
 ```

#### windows powershell install instructions

```bash
(Invoke-WebRequest -Uri https://raw.githubusercontent.com/python-poetry/poetry/master/get-poetry.py -UseBasicParsing).Content | python
```

#### pip

```bash
pip install --user poetry
```

## Usage

### Install Dependenices

```bash
poetry install
```

### Install TherMod Database

The following will install the TherMod database only:

```bash
poetry run database --TherMod
```

To download all databases:

```bash
poetry run database
```

The output directory for the database can be specified using the `--output` argument:

```bash
poetry run database --output="/path/to/database"

# Example
poetry run database --output="~/NCM_DATA"
```

The output directory can additionally be specified using the environmental variable
`NCM_DATABASE_PATH`:

```bash
export NCM_DATABASE_PATH="/path/to/database"

# Example
export NCM_DATABASE_PATH="~/NCM_DATA"
```

### Remove Database

To remove database directory:

```bash
poetry run database --clean
```

### Examples

Temperature profile at a latitude and longitude of 36,-118 from the surface to 20 km
depth in increments of 100 m.

```bash
poetry run thermod -l 36,-118 -d 0,1e2,20e3
```

Temperature profile at a latitude and longitude of 36,-118 from the surface to 20 km
depth in increments of 100 m.

```bash
poetry run thermod -f example.Input
```

### Help

Please see or query the code for help.

```bash
poetry run help
```

Any questions regarding the code can be directed to <olboyd@usgs.gov>.

## Development

### Git Hooks

The TherMod project contains githooks on pre-commit and pre-push that
will check the Python code format using [Black](https://github.com/psf/black),
check the import sorting using [isort](https://github.com/timothycrosley/isort), and
lints the code using [Flake8](https://gitlab.com/pycqa/flake8).

The GitHooks are configured with:

```bash
poetry run setup
```

### Checking the Format

To check the format of the code against Black and isort run:

```bash
poetry run format_check
```

### Formatting the Code

To automatically format the code using Black and isort run:

```bash
poetry run format
```

## References

*Boyd, O.S., 2020, Temperature Model in support of the U.S. Geological Survey
National Crustal Model for Seismic Hazard Studies: U.S. Geological Survey
Open-File Report 2019–1121, 15 p., <https://doi.org/10.3133/ofr20191121>*
